#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-IGDqZayVA0XK11bsP9R3no
key:                  coinbase-pro-0.9.3.2-IGDqZayVA0XK11bsP9R3no
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  8c95833f09f27c7853df5dbb3b1e1dc2
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-IGDqZayVA0XK11bsP9R3no
depends:
    HsOpenSSL-0.11.7.10-72aBGaewYjbEhtZXYKzg7c
    aeson-2.2.2.0-C59vZnSjH3DEmVbOnYEZqj
    aeson-casing-0.2.0.0-8I5nZ5Dmqkm6vgTjU6vHhF
    async-2.2.6-B1xPYkcAzs1LAdhNFIgAnG base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-FjAYANMmfBlCpG9zr73GDB exceptions-0.10.7
    http-api-data-0.6.1-8DFq9ajRR702g8x8SyywUw
    http-client-0.7.19-LN5QT3bQF9y5GsNu19wbhO
    http-client-tls-0.3.6.4-BpM0XRSvwZ99JZv1J5vtXV
    http-streams-0.8.9.9-D2fRAIkLs9K67oKNR10CMj
    http-types-0.12.4-57DQrkzau5HINFiGCpRQOB
    io-streams-1.5.2.2-h4AeGCmO0kLAw7dl36WEj
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-FBuTdTHZ29uBPcO3Y238RO
    servant-0.20.3.0-9NzePVuJgxzhPEQn9hLA3
    servant-client-0.20.3.0-KKf4pSldYpdImxMSGmQPYw
    servant-client-core-0.20.3.0-77jUP6MQjob86fKbZlAw17
    tasty-1.5.3-4Cw0W10idvOIHvdgaqPCw
    tasty-hunit-0.10.2-GYxBrzSptpmCw3wrbyIbJ8 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-PiexZDgxeI9iykqf47OU4
    unordered-containers-0.2.21-LjCRrPGX8vKp2UxAfh6M2
    uuid-1.3.16.1-FtFpzG0ItEW5kni5q1Y0lR
    vector-0.13.2.0-HJSwbt845rQ2AOZrNm5BDk
    websockets-0.12.7.3-FASRdo9ynG4CAodps0APLd
    wuss-2.0.1.7-HJAEY9ePASzKsMbmbtqIx1

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

